@@ -49,6 +49,10 @@ module Async
 				@buffer = Stream.new(self)
 			end
 			
+			class << self
+				alias open new
+			end
+			
 			attr :buffer
 			
 			def_delegators :@buffer, :gets, :puts, :flush
@@ -72,8 +76,19 @@ module Async
 				
 				wrapper = TCPSocket.new(peer)
 				
-				return wrapper, address
+				return wrapper, address unless block_given?
+				
+				begin
+					yield wrapper, address
+				ensure
+					wrapper.close
+				end
 			end
+			
+			alias accept_nonblock accept
+			alias sysaccept accept
+			
+			include Server
 		end
 	end
 end
